# ResultV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**orcid_identifier** | [**OrcidIdentifierV30**](OrcidIdentifierV30.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

